@@ -1,7 +1,7 @@
-# -*- coding: ascii -*-
+# -*- coding: utf-8 -*-
 #
 #  channeldialog.py - Channel selection dialog for GBottler
-#  Copyright (C) 2004 by Atzm WATANABE <sitosito@p.chan.ne.jp>
+#  Copyright (C) 2004-2010 by Atzm WATANABE <atzm@atzm.org>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -10,22 +10,22 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: channeldialog.py,v 1.3 2005/08/29 19:03:24 atzm Exp $
+# $Id: channeldialog.py,v 1.4 2010/08/22 11:04:07 atzm Exp $
 #
 
 import gtk, gobject
 from common import open_error_dialog
 
 class ChannelDialog(gtk.Dialog):
-	def __init__(self, master, channels):
+	def __init__(self, master, client):
 		self.selection = []
-		self.channels  = channels
+		self.client    = client
 
 		gtk.Dialog.__init__(self, unicode(_("Select Channels"), "utf-8"), master,
 							gtk.DIALOG_DESTROY_WITH_PARENT|gtk.DIALOG_MODAL|gtk.DIALOG_NO_SEPARATOR,
 							(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
 							 gtk.STOCK_OK, gtk.RESPONSE_OK))
-		self.set_default_size(370, 290)
+		self.set_default_size(370, 300)
 		self.connect("destroy", self.cancel, "WM destroy")
 		self.connect('response', self.res_caught)
 
@@ -73,14 +73,16 @@ class ChannelDialog(gtk.Dialog):
 			other_cols[i].set_resizable(True)
 			other_cols[i].set_clickable(False)
 
-		for n in xrange(len(self.channels)):
-			if self.channels[n]["nopost"]:
+		for name in self.client.channel_names():
+			if self.client.channels[name]["nopost"] == 1:
 				type = unicode(_("Reception only"), "utf-8")
 			else:
 				type = unicode(_("Standard"), "utf-8")
 
-			liststore.append((True, self.channels[n]["name"], type, self.channels[n]["ghost"],
-							  str(self.channels[n]["count"]), self.channels[n]["info"]))
+			liststore.append((True, name, type,
+							  self.client.channels[name]["ghost"],
+							  str(self.client.channels[name]["count"]),
+							  self.client.channels[name]["info"]))
 
 		sw = gtk.ScrolledWindow()
 		sw.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
@@ -114,7 +116,7 @@ class ChannelDialog(gtk.Dialog):
 		liststore = self.treeview.get_model()
 		for i in xrange(len(liststore)):
 			if liststore[i][0]:
-				self.selection.append(i)
+				self.selection.append(unicode(liststore[i][1], 'utf-8'))
 
 	def toggled(self, cell, path, liststore, column):
 		liststore[path][column] = not liststore[path][column]
