@@ -2,7 +2,7 @@
 #
 #  common.py - Common functions and variables for GBottler
 #  Copyright (C) 2001, 2002 by Tamito KAJIYAMA
-#  Copyright (C) 2004 by Atzm WATANABE <sitosito@p.chan.ne.jp>
+#  Copyright (C) 2004-2010 by Atzm WATANABE <atzm@atzm.org>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -11,7 +11,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: common.py,v 1.33 2009/12/28 15:22:17 atzm Exp $
+# $Id: common.py,v 1.37 2011/09/28 15:01:26 atzm Exp $
 #
 
 import os, sys
@@ -24,14 +24,11 @@ except NameError:
 
 # common defines
 APP = 'GBottler'
-VER = '0.1.7'
-
-VOTE  = "Vote"
-AGREE = "Agree"
+VER = '0.2.1'
 
 LIBDIR = "~/.bottlecase"
 
-AGENT_NAME = os.path.basename(sys.argv[0])
+AGENT_NAME = '/'.join([APP, VER])
 
 STYLE_TALK = 0
 STYLE_SCRIPT = 1
@@ -65,7 +62,7 @@ DL_SUFFIX_PATTERNS = {
 	'html': '[Hh][Tt][Mm][Ll]?',
 	}
 
-WAIT_NEXT_REQUEST = 20
+WAIT_NEXT_REQUEST = 2000
 WAIT_NEXT_LOCALGHOST_POLL = 30000
 
 # common functions
