@@ -3,8 +3,8 @@
 #
 #  gbottler.py - a SSTP Bottle Client
 #  Copyright (C) 2001, 2002 by Tamito KAJIYAMA
-#  Copyright (C) 2004-'05 by Atzm WATANABE <sitosito@p.chan.ne.jp>
 #  Copyright (C) 2004-'05 by Takuya KAWAHARA <num@sann.ne.jp>
+#  Copyright (C) 2004-2010 by Atzm WATANABE <atzm@atzm.org>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -13,7 +13,7 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: gbottler.py,v 1.183 2009/12/28 15:22:17 atzm Exp $
+# $Id: gbottler.py,v 1.188 2010/08/28 15:12:17 atzm Exp $
 #
 
 import os, sys, string, re, gettext, getopt
@@ -23,7 +23,7 @@ import pygtk
 pygtk.require('2.0')
 import gtk, gobject
 
-from bottlelib      import BottleClientError
+from bottlelib2     import BottleClientError
 from client         import Bottler
 from channeldialog  import ChannelDialog
 from localmessenger import LocalMessenger
@@ -94,31 +94,30 @@ class Application:
 		self.accel_group = self.uimanager.get_accel_group()
 		self.action_group = gtk.ActionGroup('GBottler')
 		self.action_group.add_actions([
-            ('MenuBar', None, _('_MenuBar')),
-            ('File', None, _('_File')),
-            ('Join', gtk.STOCK_NETWORK, _('Join'), '<control>j', _('Connect to Bottle Server'), self.join),
-            ('Part', gtk.STOCK_STOP, _('Part'), None, _('Disconnect from Bottle Server'), self.part),
-            ('Quit', gtk.STOCK_QUIT, _('Quit'), '<control>q', _('Quit GBottler'), self.quit),
-            ('Edit', None, _('_Edit')),
+			('MenuBar', None, _('_MenuBar')),
+			('File', None, _('_File')),
+			('Join', gtk.STOCK_NETWORK, _('Join'), '<control>j', _('Connect to Bottle Server'), self.join),
+			('Part', gtk.STOCK_STOP, _('Part'), None, _('Disconnect from Bottle Server'), self.part),
+			('Quit', gtk.STOCK_QUIT, _('Quit'), '<control>q', _('Quit GBottler'), self.quit),
+			('Edit', None, _('_Edit')),
 			('Check', gtk.STOCK_SPELL_CHECK, _('Check'), None, _('Check current script'), self.check),
 			('Test', STATE_BOTTLE_PLAYING, _('Test'), None, _('Send current script to local SSTP server only'), self.test),
 			('Send', gtk.STOCK_OK, _('Send'), None, _('Send current script to Bottle server'), self.send_question),
 			('ResetEditor', gtk.STOCK_CLEAR, _('Reset editor'), None, _('Reset editor'), self.edit_reset),
 			('ClearEditor', gtk.STOCK_CLEAR, _('Clear editor'), None, _('Clear editor'), self.edit_clear_all),
-			#('SavePhrases', gtk.STOCK_SAVE_AS, _('Save as phrases...'), None, _('Save current script as phrases'), self.save_phrases),
 			('Cut', gtk.STOCK_CUT, _('Cu_t'), '<control>x', _('Cut'), self.edit_cut),
 			('Copy', gtk.STOCK_COPY, _('_Copy'), '<control>c', _('Copy'), self.edit_copy),
 			('Paste', gtk.STOCK_PASTE, _('Paste'), '<control>v', _('Paste'), self.edit_paste),
 			('Delete', gtk.STOCK_DELETE, _('_Delete'), 'Delete', _('Delete'), self.edit_delete),
-            ('Preferences', gtk.STOCK_PREFERENCES, _('_Preferences...'), None, _('Edit preferences'), self.open_preference),
-            ('Window', None, _('_Window')),
+			('Preferences', gtk.STOCK_PREFERENCES, _('_Preferences...'), None, _('Edit preferences'), self.open_preference),
+			('Window', None, _('_Window')),
 			('LogWindow', None, _('Log window'), '<control>l', _('Open log window'), lambda x: self.logwindow.open(x)),
 			('PhraseEditor', None, _('Phrase editor'), None, _('Open phrase editor window'), lambda x: self.phrase_editor.open_window(x)),
 			('GViewer', None, _('GViewer'), None, _('Open GViewer window'), self.open_gviewer),
 			('SVGManager', None, _('SVGManager'), None, _('Open SVGManager window'), lambda x: self.svgmanager.open(x)),
-            ('Help', None, _('_Help')),
-            ('About', gtk.STOCK_ABOUT, _('About'), None, _('About GBottler'), self.about),
-            ])
+			('Help', None, _('_Help')),
+			('About', gtk.STOCK_ABOUT, _('About'), None, _('About GBottler'), self.about),
+			])
 		self.action_group.add_toggle_actions([
 			('HidePhraseBar', None, _('Hide phrase bar'), None, _('Hide phrase bar'), lambda x: self.phrase_bar.set_property('visible', not x.get_active())),
 			])
@@ -184,9 +183,7 @@ class Application:
 		self.textmanager = TextManager(self)
 		self.textmanager.set_style_script()
 		self.textmanager.grab_focus()
-
-		self.editor = self.textmanager.get_buffer()
-		self.editor.connect('end-user-action', self.editor_modified)
+		self.textmanager.connect_textbuffer('end-user-action', self.editor_modified)
 
 		sw = gtk.ScrolledWindow()
 		sw.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
@@ -219,20 +216,14 @@ class Application:
 		main_vbox.pack_start(main_paned, True, True, 0) # main editor and progressbar
 
 # === Initialization of Application === #
-		[str, pos] = self.get_initial_script()
-		self.textmanager.insert_with_color_from(str, pos)
-		self.editor_modified()
-
-		self.client = Bottler(self)
-		self.client.debug = 2
+		self.edit_reset()
 
 		try:
 			luid = open(os.path.join(open_bottlecase(), "luid")).read()
 		except IOError:
-			luid = None
-		if luid and len(luid) == 82:
-			self.client.luid = luid
+			luid = ''
 
+		self.client = Bottler(self, luid)
 		self.logwindow = LogWindow(self)
 
 		ghostmanager    = GhostManager(os.path.join(open_bottlecase(), 'gviewer', 'ghost.txt'))
@@ -329,7 +320,7 @@ class Application:
 		return [scr, n]
 
 	def notify_preferences_changed(self):
-		for child in [self.logwindow, self.gvwindow, self.textmanager]:
+		for child in [self.logwindow, self.gvwindow, self.textmanager, self.client]:
 			child.receive_preferences_changed()
 
 	def notify_svg_changed(self):
@@ -362,8 +353,7 @@ class Application:
 
 	def editor_modified(self, widget=None, event=None):
 		self.textmanager.coloring(widget, event)
-		[si, ei] = self.editor.get_bounds()
-		script = self.editor.get_text(si, ei)
+		script = self.textmanager.get_text()
 		self.sbar.pop(0)
 		try:
 			self.sbar.push(0, str(len(script.encode('sjis'))) + unicode(_('bytes'), 'utf-8'))
@@ -371,25 +361,26 @@ class Application:
 			self.sbar.push(0, str(len(script)) + unicode(_('bytes'), 'utf-8'))
 
 	def join(self, widget=None, *args):
-		if self.client.connected:
+		if self.client.joined_channels:
 			return
 
-		if not self.client.initialized:
-			try:
-				self.client.init()
-			except BottleClientError, e:
-				return
-			filename = os.path.join(open_bottlecase(), "luid")
-			try:
-				open(filename, "w").write(self.client.luid)
-			except IOError:
-				self.monitor_insert("\n" + unicode(_("Warning"), "utf-8") + \
-									": cannot write " + filename)
+		try:
+			self.client.start()
+		except BottleClientError, e:
+			self.monitor_insert("\n" + unicode(_("Error"), "utf-8") + ": " + str(e))
+			return
+
+		filename = os.path.join(open_bottlecase(), "luid")
+		try:
+			open(filename, "w").write(self.client.luid)
+		except IOError:
+			self.monitor_insert("\n" + unicode(_("Warning"), "utf-8") + \
+								": cannot write " + filename)
 
 		if config.get('general', 'connect_all', 'boolean'):
-			channels = range(len(self.client.channels))
+			channels = self.client.channel_names()
 		else:
-			d = ChannelDialog(self.window, self.client.channels)
+			d = ChannelDialog(self.window, self.client)
 			d.run()
 			channels = d.selection
 			d.destroy()
@@ -399,7 +390,11 @@ class Application:
 
 		if not channels:
 			return
-		if self.client.join(channels):
+
+		try:
+			self.client.join(channels)
+		except BottleClientError, e:
+			self.part()
 			return
 
 		self.pbar.set_fraction(0.0)
@@ -411,7 +406,7 @@ class Application:
 		if self._timeout_id:
 			gobject.source_remove(self._timeout_id)
 			self._timeout_id = None
-		self.client.close()
+		self.client.finish()
 		self.disable_channel()
 		self.monitor_clear()
 		self.monitor_insert(unicode(_("Connection closed."), "utf8"))
@@ -422,11 +417,11 @@ class Application:
 	def enable_channel(self):
 		self.channel_combo.popdown()
 		model = self.channel_combo.get_model()
-		channel = self.channel_combo.get_active_text()
+		channel = self.get_selected_channel()
 
 		model.clear()
-		for n in self.client.in_channels:
-			self.channel_combo.append_text(self.client.channels[n]["name"])
+		for channel in self.client.joined_channels:
+			self.channel_combo.append_text(channel)
 
 		if 0 < len(model) and channel is None:
 			self.channel_combo.set_active(0)
@@ -452,12 +447,11 @@ class Application:
 		self.users.set_text('')
 
 	def update_channel(self, widget=None, *args):
-		try:
-			_id = self.get_channel_id()
-		except RuntimeError:
+		channel = self.get_selected_channel()
+		if not channel:
 			# disable_channel() clears channel_combo
 			return
-		self.show_users_of(_id)
+		self.show_users_of(channel)
 		self.check_channel_permission()
 
 	def close_channel(self, name):
@@ -466,20 +460,21 @@ class Application:
 		self.monitor_insert(name + _('channel was closed.'))
 
 	def check_channel_permission(self):
-		channel = self.get_channel_id()
-		if self.client.channels[channel]["nopost"]:
+		channel = self.get_selected_channel()
+		if channel not in self.client.channels:
+			return
+		if self.client.channels[channel]["nopost"] == 1:
 			self.send_button.set_sensitive(False)
 			self.uimanager.get_widget('/MenuBar/Edit/Send').set_sensitive(False)
 		else:
 			self.send_button.set_sensitive(True)
 			self.uimanager.get_widget('/MenuBar/Edit/Send').set_sensitive(True)
 
-	def get_channel_id(self):
-		name = self.channel_combo.get_active_text()
-		for i in self.client.in_channels:
-			if self.client.channels[i]["name"] == name:
-				return i
-		raise RuntimeError, "unknown channel name (%s)" % name
+	def get_selected_channel(self):
+		channel = self.channel_combo.get_active_text()
+		if channel:
+			channel = unicode(channel, 'utf-8')
+		return channel
 
 	def uniq_ghosts(self, misc=[]):
 		ghosts = uniq(misc + self.local_ghost + self.svgmanager.get_fmo_ghostnames())
@@ -500,9 +495,10 @@ class Application:
 		model.clear()
 
 		ghosts = [self.DEFAULT_TARGET]
-		if self.client.connected:
-			ghosts += [c['ghost'] for c in self.client.channels]
+		if self.client.joined_channels:
+			ghosts += [c['ghost'] for c in self.client.channels.values()]
 		ghosts = self.uniq_ghosts(ghosts)
+		ghosts.sort()
 
 		for g in ghosts:
 			self.ghost_combo.append_text(g)
@@ -513,7 +509,7 @@ class Application:
 		else:
 			self.ghost_combo.set_active(0)
 
-		if self.client.connected:
+		if self.client.joined_channels:
 			self.check_channel_permission()
 
 	def handle_localghost(self):
@@ -522,16 +518,14 @@ class Application:
 		return True
 
 	def handle_event(self):
-		if not self.client.connected:
+		if not self.client.joined_channels:
 			self.part()
 			return False
-		handled = 0
 		try:
-			handled = self.client.handle_event()
+			self.client.handle_event()
 		except BottleClientError, e:
-			self.client.close()
-			self.disable_channel()
 			self.part()
+			self.monitor_insert("\n" + unicode(_("Error"), "utf-8") + ": " + str(e))
 			return False
 
 		return True
@@ -540,19 +534,6 @@ class Application:
 		if event.button in [1, 3]:
 			sender.popup(None, widget, None, event.button, event.time)
 
-	def save_phrases(self, widget=None, *args):
-		regexp = re.compile('\r?\n')
-
-		title = regexp.sub('', open_simple_entry_dialog(_('Please input title'),
-														_('Please input title'),
-														parent=self.window))
-		script = regexp.sub('', self.textmanager.get_script())
-
-		if title and script:
-			pm = PhraseManager()
-			pm.append("%s\t%s" % (title, script))
-			pm.save_database()
-
 	def send_question(self, widget=None, *args):
 		self.textmanager.grab_focus()
 		if self.check(widget, *args):
@@ -570,7 +551,7 @@ class Application:
 		if not res or res != gtk.RESPONSE_YES:
 			return
 
-		channel = self.get_channel_id()
+		channel = self.get_selected_channel()
 		script = self.get_script()
 		if target_ghost == self.DEFAULT_TARGET:
 			target_ghost = None
@@ -627,20 +608,19 @@ class Application:
 			return False
 
 	def get_script(self):
-		[si, ei] = self.editor.get_bounds()
-		script = string.replace(self.editor.get_text(si, ei), "\n", "")
+		script = string.replace(self.textmanager.get_text(), "\n", "")
 
 		if string.rstrip(script)[-2:] != r"\e":
 			script = script + r"\e"
 		return unicode(script, "utf-8")
 
 	def show_users(self):
-		channel = self.get_channel_id()
+		channel = self.get_selected_channel()
 		count = self.client.channels[channel]["count"]
 		self.users.set_text("%d/%d " % (count, self.client.users))
 
 	def show_users_of(self, channel):
-		if channel == self.get_channel_id():
+		if channel == self.get_selected_channel():
 			count = self.client.channels[channel]["count"]
 			self.users.set_text("%d/%d " % (count, self.client.users))
 
@@ -675,7 +655,7 @@ class Application:
 
 	def edit_clear_all(self, widget=None, *args):
 		self.monitor_clear()
-		self.editor.set_text('')
+		self.textmanager.set_text('')
 		self.sbar.pop(0)
 		self.sbar.push(0, '0' + _('bytes'))
 
@@ -1037,9 +1017,9 @@ Public License instead of this License."""
 		gtk.AboutDialog.__init__(self)
 		self.set_name(APP)
 		self.set_version(VER)
-		self.set_copyright("Copyright (C) 2004-'09 GBottler Project all rights reserved")
+		self.set_copyright("Copyright (C) 2004-'10 GBottler Project all rights reserved")
 		self.set_authors([
-			"Copyright (C) 2004-'09 Atzm WATANABE",
+			"Copyright (C) 2004-'10 Atzm WATANABE",
 			"Copyright (C) 2004-'05 Takuya Kawahara",
 			"Copyright (C) 2001-'02 Tamito KAJIYAMA",
 		])
@@ -1048,56 +1028,58 @@ Public License instead of this License."""
 		self.connect('delete-event', lambda x, y: self.destroy())
 
 def usage():
-	port = unicode(_("alternative port for forwarding SSTP messages"), 'utf-8').encode('euc-jp')
-	help = unicode(_("show this message"), 'utf-8').encode('euc-jp')
-	host = unicode(_("alternative host for forwarding SSTP messages"), 'utf-8').encode('euc-jp')
+	name_  = os.path.basename(sys.argv[0])
+	port_  = unicode(_('alternative port for forwarding SSTP messages'), 'utf-8')
+	help_  = unicode(_('show this message'), 'utf-8')
+	host_  = unicode(_('alternative host for forwarding SSTP messages'), 'utf-8')
+	usage  = unicode(_('Usage'), 'utf-8')
+	option = unicode(_('Options'), 'utf-8')
 
-	usage = """\
-	-p, --port NUM  %s
-	--host HOST     %s
-	-h, --help      %s\n""" % (port, host, help)
+	helpstr = '''
+%(usage)s
+    %(name_)s [%(option)s]
 
-	sys.stderr.write(unicode(_("Usage"), 'utf-8').encode('euc-jp') + ": " + \
-					 AGENT_NAME + "\n" + \
-					 unicode(_("Options"), 'utf-8').encode('euc-jp') + ":\n" + usage)
-	sys.exit(1)
+%(option)s
+    --port (-p)  NUM      %(port_)s
+    --host       HOST     %(host_)s
+    --help (-h)           %(help_)s
+''' % locals()
+
+	print >> sys.stderr, helpstr.strip()
+	raise SystemExit
 
 def main():
-	# parse command line arguments
 	try:
-		options, rest = getopt.getopt(sys.argv[1:], "p:h",
-									  ["port=", "help", "host="])
+		options, rest = getopt.getopt(sys.argv[1:], 'p:h', ['port=', 'help', 'host='])
 	except getopt.error, e:
-		sys.stderr.write(unicode(_("Error"), 'utf-8').encode('euc-jp') + ": %s\n" % str(e))
+		print >> sys.stderr, unicode(_('Error'), 'utf-8'), ':', str(e), '\n'
 		usage()
+
 	if rest:
 		usage()
 
 	port = 9801
-	host = "localhost"
+	host = 'localhost'
 
-	# check environment variables
-	val = os.environ.get("BOTTLER_PORT")
+	val = os.environ.get('BOTTLER_PORT')
 	if val:
 		try:
 			num = int(val)
 		except ValueError:
-			sys.stderr.write(unicode(_("Invalid BOTTLER_PORT number (ignored)") + \
-									 "\n", 'utf-8').encode('euc-jp'))
+			print >> sys.stderr, unicode(_('Invalid BOTTLER_PORT number (ignored)'), 'utf-8')
 		else:
 			port = num
 
-	# parse command line options
 	for opt, val in options:
-		if opt in ["-p", "--port"]:
+		if opt in ['-p', '--port']:
 			port = int(val)
-		elif opt == "--host":
+		elif opt == '--host':
 			host = val
 		else:
 			usage()
-	# run
+
 	app = Application(host, port)
 	app.main()
 
-if __name__ == "__main__":
+if __name__ == '__main__':
 	main()
