@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 #  logfetcher.py - Log Downloader
-#  Copyright (C) 2004 by Atzm WATANABE <sitosito@p.chan.ne.jp>
+#  Copyright (C) 2004-2010 by Atzm WATANABE <atzm@atzm.org>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -10,45 +10,48 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: logfetcher.py,v 1.2 2009/12/08 14:21:11 atzm Exp $
+# $Id: logfetcher.py,v 1.4 2010/08/22 11:04:07 atzm Exp $
 #
 
-import mimetools, socket, httplib
-import string
+import urllib
+import mimetools
+import traceback
+
+try:
+	import cStringIO as _StringIO
+except ImportError:
+	import StringIO as _StringIO
 
 import config
 from common import AGENT_NAME
 
+class LogFetchURLopener(urllib.URLopener):
+	version = AGENT_NAME
+
 class LogFetcher:
 	def __init__(self):
-		pass
+		self.url = 'http://bottle.mikage.to/fetchlog.cgi'
 
-	def fetch(self, request, action='/fetchlog.cgi'):
-		try:
-			http = httplib.HTTP(config.get('slpp_server', 'http_conn'),
-								config.get('slpp_server', 'http_port', 'int'))
+	def fetch(self, request):
+		proxy = config.get('http_server', 'http_proxy').strip()
 
-			http.putrequest("POST", action)
-			http.putheader("Host", config.get('slpp_server', 'http_host'))
-			http.putheader("From", AGENT_NAME)
-			http.putheader("Accept", "text/html, text/plain")
-			http.putheader("Content-type", "application/x-www-form-urlencoded")
-			http.putheader("Content-length", str(len(request)))
-			http.endheaders()
-
-			http.send(request)
-		except socket.error, e:
-			print e
-			return str(e)
+		if proxy:
+			proxy = {'http': proxy}
+		else:
+			proxy = None
 
 		try:
-			code, message, headers = http.getreply()
-		except socket.error, e:
-			print e
-			return str(e)
+			req = self.url + '?' + request
+			fil = LogFetchURLopener(proxies=proxy).open(req)
+			sio = _StringIO.StringIO(fil.read())
+			code = fil.getcode()
+			fil.close()
+		except:
+			s = _StringIO.StringIO()
+			traceback.print_exc(file=s)
+			return s.getvalue()
 
-		file = http.getfile()
-		headers = mimetools.Message(file, 0)
+		headers = mimetools.Message(sio, 0)
 
 		if code != 200:
 			#print code, message, headers
@@ -62,7 +65,7 @@ class LogFetcher:
 
 		lines = []
 		while True:
-			line = file.readline()
+			line = sio.readline()
 			if not line:
 				break
 			if line[-2:] == '\r\n':
@@ -70,7 +73,7 @@ class LogFetcher:
 			if not line:
 				continue
 			line = unicode(line, 'sjis', 'replace')
-			[date, mid, channel, ghost, users, votes, agrees, script] = string.split(line, '\t', 7)
+			[date, mid, channel, ghost, users, votes, agrees, script] = line.split('\t', 7)
 			lines.append([date, mid, votes, agrees, channel, ghost, script])
 
 		return lines
