@@ -2,7 +2,7 @@
 #
 #  logwindow.py - Log window for GBottler
 #  Copyright (C) 2001, 2002 by Tamito KAJIYAMA
-#  Copyright (C) 2004 by Atzm WATANABE <sitosito@p.chan.ne.jp>
+#  Copyright (C) 2004-2010 by Atzm WATANABE <atzm@atzm.org>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -11,13 +11,11 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: logwindow.py,v 1.38 2009/12/13 19:06:08 atzm Exp $
+# $Id: logwindow.py,v 1.40 2010/08/22 11:04:07 atzm Exp $
 #
 
 import gtk, gobject
 import os, time
-#import gc
-#gc.set_debug(gc.DEBUG_LEAK)
 
 from logfetchdialog import LogFetchDialog
 from textmanager    import TextManager
@@ -548,7 +546,7 @@ class LogWindow:
 				self.select(list)
 
 	def update(self, mid, channel, ghost, script, receive_time):
-		datetime = time.strftime("%y/%m/%d %H:%M:%S", receive_time)
+		datetime = time.strftime("%y/%m/%d %H:%M:%S", time.localtime(receive_time))
 		close_button, eventbox, child = self.logbook.update(mid, channel, ghost, script, datetime)
 
 		if child and close_button and eventbox:
@@ -600,7 +598,7 @@ class LogWindow:
 		self.sbar.pop(0)
 		self.rowsbar.pop(0)
 		self.curr_rowsbar.pop(0)
-		self.textmanager.clear()
+		self.textmanager.set_text('')
 
 	def update_rows(self, list):
 		if list and list.rows():
@@ -731,7 +729,7 @@ class LogWindow:
 			self.play(loglist, event)
 
 	def select(self, loglist, se=False):
-		self.textmanager.clear()
+		self.textmanager.set_text('')
 		row = loglist.selection()
 		script = unicode(loglist.get_text(row, LogList.LISTSTORE_SCRIPT), "utf-8", 'replace')
 		self.textmanager.insert_with_color_from(script)
@@ -774,12 +772,6 @@ class LogWindow:
 	def focus_active_loglist(self, widget=None, data=None):
 		self.logbook.focus_active_loglist()
 
-	#def check_message_bar(self, data=None, widget=None):
-	#	if widget.get_active():
-	#		self.msgframe.hide()
-	#	else:
-	#		self.msgframe.show()
-
 	### notify preference changed start
 	def tab_pos_changed(self):
 		pos = config.get('logwindow', 'tab_placement', 'int')
