@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 #
 #  phrasemanager.py - new phrase manager
-#  Copyright (C) 2005 by Atzm WATANABE <sitosito@p.chan.ne.jp>
+#  Copyright (C) 2005 by Atzm WATANABE <atzm@atzm.org>
 #
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License (version 2) as
@@ -11,10 +11,10 @@
 #  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 #  PURPOSE.  See the GNU General Public License for more details.
 #
-# $Id: phrasemanager.py,v 1.10 2005/10/11 10:28:56 atzm Exp $
+# $Id: phrasemanager.py,v 1.12 2010/08/28 15:12:17 atzm Exp $
 #
 
-__version__ = '$Revision: 1.10 $'
+__version__ = '$Revision: 1.12 $'
 __author__ = '$Author: atzm $'
 
 import os, sys
@@ -306,6 +306,9 @@ class PhraseEditor(gtk.Window):
 		self.treeview.set_rules_hint(True)
 		self.treeview.set_search_column(True)
 		self.treeview.set_enable_search(True)
+		self.treeview.set_reorderable(True)
+		self.treeview.connect('drag-drop', self.drag_drop_cb)
+		self.treeview.connect('drag-end', self.drag_end_cb)
 		self.treeview.connect('cursor-changed', self.selected)
 		self.treeview.connect('row-expanded', lambda *args: self.treeview.columns_autosize())
 		self.treeview.connect('row-collapsed', lambda *args: self.treeview.columns_autosize())
@@ -336,7 +339,7 @@ class PhraseEditor(gtk.Window):
 			('New', gtk.STOCK_FILE, _('_New'), None, _('Insert new item'), self.new),
 			('Append', gtk.STOCK_DIRECTORY, _('_Append'), None, _('Append submenu to item'), self.append),
 			('Delete', gtk.STOCK_DELETE, _('_Delete'), None, _('Delete selected item'), self.delete),
-            ('Down', gtk.STOCK_GO_DOWN, _('Down'), None, _('Go down selected item'), self.go_down),
+			('Down', gtk.STOCK_GO_DOWN, _('Down'), None, _('Go down selected item'), self.go_down),
 			])
 		self._uimanager.insert_action_group(self._actiongroup, 0)
 		self.ui_merge_id = self._uimanager.add_ui_from_string(self.MENU_STRING)
@@ -354,6 +357,30 @@ class PhraseEditor(gtk.Window):
 		self.set_default_size(config.get('phraseeditor', 'width', 'int'),
 							  config.get('phraseeditor', 'height', 'int'))
 
+	def drag_drop_cb(self, treeview, context, x, y, etime):
+		drop_info = treeview.get_dest_row_at_pos(x, y)
+		if not drop_info:
+			context.finish(False, False, etime)
+			return True
+		path, pos = drop_info
+		model = treeview.get_model()
+		iter_root = model.get_iter_root()
+		iter_ = model.get_iter(path)
+		if model.get_path(iter_root) == model.get_path(iter_):
+			if pos in [gtk.TREE_VIEW_DROP_BEFORE, gtk.TREE_VIEW_DROP_AFTER]:
+				context.finish(False, False, etime)
+				open_error_dialog(_("Can't modify root menu."), self)
+				return True
+		if model.get_value(iter_, 1) or model.get_value(iter_, 2):
+			if pos in [gtk.TREE_VIEW_DROP_INTO_OR_BEFORE, gtk.TREE_VIEW_DROP_INTO_OR_AFTER]:
+				context.finish(False, False, etime)
+				open_error_dialog(_("Can't add 'insert string' or 'key accelerator' to menu."), self)
+				return True
+		context.finish(True, False, etime)
+
+	def drag_end_cb(self, treeview, context):
+		self.update_notify()
+
 	def go_down(self, widget=None, *data):
 		model = self.treeview.get_model()
 
